===================
 Interesting Links
===================


ElasticSearch
-------------

* IRC channel ``#elasticsearch`` (Freenode)

* `ElasticSearch`_: Search Engine for the cloud.

.. _`ElasticSearch`: http://www.elasticsearch.com/
